//========================================================================================
//	Release Version:	$ ODF 1 $
//	Copyright:	(c) 1993 - 1996 by Apple Computer, Inc., all rights reserved.

//================================================================================
#include "Graphics3D.hpp"

#ifndef PART_H
#include "Part.h"
#endif

#ifndef CONTENT_H
#include "Content.h"
#endif

#ifndef BINDING_K
#include "Binding.k"
#endif

#ifndef FRAME_H
#include "Frame.h"
#endif

#ifndef SELECTION_H
#include "Selection.h"
#endif

#ifndef DEFINES_K
#include "Defines.k"			// command numbers
#endif

// ----- Framework Layer -----
#ifndef FWPRESEN_H
#include "FWPresen.h"		// FW_CPresentation
#endif

#ifndef FWUTIL_H
#include "FWUtil.h"			// FW_Beep()
#endif

#ifndef FWABOUT_H
#include "FWAbout.h"		//::FW_About()
#endif

// ----- OS Layer -----
#ifndef FWMENU_H
#include "FWMenu.h"			// FW_CMenuBar, FW_CPullDownMenu
#endif

#ifndef FWCFMRES_H
#include "FWCFMRes.h"		// FW_CSharedLibraryResourceFile
#endif

#ifndef FWRESTYP_H
#include "FWResTyp.h"		// MULTISTRINGRES
#endif

#ifndef FWEVENT_H
#include "FWEvent.h"		// FW_CMenuEvent
#endif

#ifndef FWSUSINK_H
#include "FWSUSink.h"		// FW_CStorageUnitSink
#endif

#ifndef FWBARRAY_H
#include "FWBArray.h"		// FW_CByteArray
#endif

// ----- Foundation Layer -----
#ifndef FWSTREAM_H
#include <FWStream.h>		// FW_InitializeArchiving
#endif

#ifndef FWMEMMGR_H
#include "FWMemMgr.h"		// FW_CMemoryManager
#endif

#ifndef FWSUSINK_H
#include "FWSUSink.h"		// FW_CStorageUnitSink
#endif

//==============================================================================
#ifdef FW_BUILD_MAC
#pragma segment Graphics3D
#endif

FW_DEFINE_AUTO(CGraphics3DPart)

//==============================================================================
CGraphics3DPart::CGraphics3DPart(ODPart* odPart)
  :	FW_CPart(odPart, FW_gInstance, kPartInfoID),
	fPresentation(NULL),
	fPartContent(NULL)
{
}

//--------------------------------------------------------------------------------
CGraphics3DPart::~CGraphics3DPart()
{
}

//--------------------------------------------------------------------------------
void 
CGraphics3DPart::Initialize(Environment* ev)	// Override
{
	FW_CPart::Initialize(ev);
	CGraphics3DSelection* selection = FW_NEW(CGraphics3DSelection, (ev, fPartContent));
	const ODType kMainPresentation = "Apple:Presentation:Graphics3D";
	const FW_Boolean kDefaultPresentation = true;
	fPresentation = RegisterPresentation(ev, kMainPresentation, 
											kDefaultPresentation, selection);
	FW_CSharedLibraryResourceFile resFile(ev);
	GetMenuBar(ev)->InitializeFromResource(ev, kMenuBarID);
}

//--------------------------------------------------------------------------------
FW_Boolean 
CGraphics3DPart::DoMenu(Environment* ev, const FW_CMenuEvent& theMenuEvent)	// Override
{
	FW_Boolean menuHandled = true;
	switch (theMenuEvent.GetCommandID(ev))
	{
		case kODCommandAbout:
			::FW_About(ev, this, kAbout);
			break;

		default:
			menuHandled = false;
	}
	
	return menuHandled;
}

//--------------------------------------------------------------------------------
FW_CFrame* 
CGraphics3DPart::NewFrame(Environment* ev, ODFrame* odFrame,
						FW_CPresentation* presentation, FW_Boolean fromStorage)	// Override
{
	FW_UNUSED(presentation);
	FW_UNUSED(fromStorage);
	return FW_NEW(CGraphics3DFrame, (ev, odFrame, presentation, fPartContent));
}

//------------------------------------------------------------------------------
FW_CContent* 
CGraphics3DPart::NewPartContent(Environment* ev)
{
	fPartContent = FW_NEW(CGraphics3DContent, (ev, this));
	return fPartContent;
}
